# ManyOrgTokenIntrospectResponse

Response object for a multi-org introspection
## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**sub_org_results** | [**list[Token]**](Token.md) | List of sub org&#39;s tokens | 
**primary_token** | [**Token**](Token.md) |  | 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


